@@ -137,10 +137,10 @@ pub async fn create_client(
         };
         HeaderValue::from_str(&host)?
     };
-    if let Some(path) = &args.http_headers_file {
-        if !path.exists() {
-            panic!("http headers file does not exists: {}", path.display());
-        }
+    if let Some(path) = &args.http_headers_file
+        && !path.exists()
+    {
+        panic!("http headers file does not exists: {}", path.display());
     }
 
     let client_config = WsClientConfig {
@@ -291,6 +291,7 @@ async fn create_client_tunnels(
             }
             LocalProtocol::ReverseUnix { path } => {
                 let path = path.clone();
+                info!("Connecting to unix socket {:?}", tunnel);
                 spawn_tunnel! {
                     let cfg = client.config.clone();
                     let tcp_connector = TcpTunnelConnector::new(
@@ -529,7 +530,7 @@ async fn run_server_impl(args: Server, executor: impl TokioExecutorRef) -> anyho
         env!("CARGO_PKG_VERSION"),
         server.config
     );
-    debug!("Restriction rules: {:#?}", restrictions);
+    debug!("Restriction rules: {restrictions:#?}");
     server.serve(restrictions).await
 }
 
@@ -545,7 +546,7 @@ fn mk_http_proxy(
     let mut proxy = if proxy.starts_with("http://") {
         Url::parse(&proxy).with_context(|| "Invalid http proxy url")?
     } else {
-        Url::parse(&format!("http://{}", proxy)).with_context(|| "Invalid http proxy url")?
+        Url::parse(&format!("http://{proxy}")).with_context(|| "Invalid http proxy url")?
     };
 
     if let Some(login) = proxy_login {
