@@ -46,7 +46,7 @@ impl UdpServer {
         const BUF_SIZES: [usize; 7] = [64usize, 32usize, 16usize, 8usize, 4usize, 2usize, 1usize];
         for size in BUF_SIZES.iter() {
             if let Err(err) = socket.set_recv_buffer_size(size * 1024 * 1024) {
-                warn!("Cannot increase UDP server recv buffer to {} Mib: {}", size, err);
+                warn!("Cannot increase UDP server recv buffer to {size} Mib: {err}");
                 warn!(
                     "This is not fatal, but can lead to packet loss if you have too much throughput. You must monitor packet loss in this case"
                 );
@@ -62,7 +62,7 @@ impl UdpServer {
 
         for size in BUF_SIZES.iter() {
             if let Err(err) = socket.set_send_buffer_size(size * 1024 * 1024) {
-                warn!("Cannot increase UDP server send buffer to {} Mib: {}", size, err);
+                warn!("Cannot increase UDP server send buffer to {size} Mib: {err}");
                 warn!(
                     "This is not fatal, but can lead to packet loss if you have too much throughput. You must monitor packet loss in this case"
                 );
@@ -183,18 +183,18 @@ impl AsyncRead for UdpStream {
     fn poll_read(self: Pin<&mut Self>, cx: &mut task::Context<'_>, obuf: &mut ReadBuf<'_>) -> Poll<io::Result<()>> {
         let mut project = self.project();
         // Look that the timeout for client has not elapsed
-        if let Some(mut deadline) = project.watchdog_deadline.as_pin_mut() {
-            if deadline.poll_tick(cx).is_ready() {
-                if !*project.data_read_before_deadline {
-                    return Poll::Ready(Err(Error::new(
-                        ErrorKind::TimedOut,
-                        format!("UDP stream timeout with {}", project.peer),
-                    )));
-                };
+        if let Some(mut deadline) = project.watchdog_deadline.as_pin_mut()
+            && deadline.poll_tick(cx).is_ready()
+        {
+            if !*project.data_read_before_deadline {
+                return Poll::Ready(Err(Error::new(
+                    ErrorKind::TimedOut,
+                    format!("UDP stream timeout with {}", project.peer),
+                )));
+            };
 
-                *project.data_read_before_deadline = false;
-                while deadline.poll_tick(cx).is_ready() {}
-            }
+            *project.data_read_before_deadline = false;
+            while deadline.poll_tick(cx).is_ready() {}
         }
 
         if let Some(notified) = project.pending_notification.as_mut().as_pin_mut() {
@@ -251,7 +251,7 @@ pub async fn run_server(
 
     let listener = UdpSocket::bind(bind)
         .await
-        .with_context(|| format!("Cannot create UDP server {:?}", bind))?;
+        .with_context(|| format!("Cannot create UDP server {bind:?}"))?;
     configure_listener(&listener)?;
 
     let udp_server = UdpServer::new(listener, timeout);
@@ -259,10 +259,10 @@ pub async fn run_server(
         (udp_server, None, mk_send_socket),
         |(mut server, peer_with_data, mk_send_socket)| async move {
             // New returned peer hasn't read its data yet, await for it.
-            if let Some(await_peer) = peer_with_data {
-                if let Some(peer) = server.peers.get(&await_peer) {
-                    peer.has_read_data.notified().await;
-                }
+            if let Some(await_peer) = peer_with_data
+                && let Some(peer) = server.peers.get(&await_peer)
+            {
+                peer.has_read_data.notified().await;
             };
 
             loop {
@@ -347,7 +347,7 @@ pub async fn connect(
         Host::Domain(domain) => dns_resolver
             .lookup_host(domain.as_str(), port)
             .await
-            .with_context(|| format!("cannot resolve domain: {}", domain))?,
+            .with_context(|| format!("cannot resolve domain: {domain}"))?,
         Host::Ipv4(ip) => vec![SocketAddr::V4(SocketAddrV4::new(*ip, port))],
         Host::Ipv6(ip) => vec![SocketAddr::V6(SocketAddrV6::new(*ip, port, 0, 0))],
     };
@@ -365,7 +365,7 @@ pub async fn connect(
         let socket = match socket {
             Ok(socket) => socket,
             Err(err) => {
-                warn!("cannot bind udp socket {:?}", err);
+                warn!("cannot bind udp socket {err:?}");
                 continue;
             }
         };
@@ -425,7 +425,7 @@ pub async fn connect(
     if let Some(cnx) = cnx {
         Ok(WsUdpSocket::new(Arc::new(cnx)))
     } else {
-        Err(anyhow!("Cannot connect to udp peer {}:{} reason {:?}", host, port, last_err))
+        Err(anyhow!("Cannot connect to udp peer {host}:{port} reason {last_err:?}"))
     }
 }
 
@@ -434,7 +434,7 @@ pub fn configure_tproxy(listener: &UdpSocket) -> anyhow::Result<()> {
     use std::net::IpAddr;
     use std::os::fd::AsFd;
 
-    socket2::SockRef::from(&listener).set_ip_transparent(true)?;
+    socket2::SockRef::from(&listener).set_ip_transparent_v4(true)?;
     match listener.local_addr().unwrap().ip() {
         IpAddr::V4(_) => {
             nix::sys::socket::setsockopt(&listener.as_fd(), nix::sys::socket::sockopt::Ipv4OrigDstAddr, &true)?;
@@ -482,13 +482,13 @@ pub fn mk_send_socket_tproxy(listener: &Arc<UdpSocket>) -> anyhow::Result<Arc<Ud
                 );
             }
             _ => {
-                warn!("Unknown control message {:?}", cmsg);
+                warn!("Unknown control message {cmsg:?}");
             }
         }
     }
 
     let socket = Socket::new(Domain::for_address(remote_addr), Type::DGRAM, Some(Protocol::UDP))?;
-    socket.set_ip_transparent(true)?;
+    socket.set_ip_transparent_v4(true)?;
     socket.set_reuse_address(true)?;
     socket.set_reuse_port(true)?;
     socket.bind(&SockAddr::from(remote_addr))?;
